==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/de.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informationen zur CPU nicht verfügbar",
    "Load average" : "Durchschnittsauslastung",
    "Last minute" : "Letzte Minute",
    "Memory info not available" : "Informationen zum Arbeitsspeicher nicht verfügbar",
    "Total" : "Gesamt",
    "Current usage" : "Aktuelle Nutzung",
    "Users" : "Benutzer",
    "Groups" : "Gruppen",
    "Links" : "Verknüpfungen",
    "Federated sent" : "Federated gesendet",
    "Federated received" : "Federated empfangen",
    "Last 24 hours" : "Letzte 24 Stunden",
    "Last 1 hour" : "Letzte Stunde",
    "Last 5 mins" : "Letzte 5 Minuten",
    "Copy" : "Kopieren",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Ctrl-C zum Kopieren drücken.",
    "Monitoring" : "Information",
    "Monitoring app with useful server information" : "Monitoring-App mit nützlichen Serverinformationen",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zeigt nützliche Informationen des Servers an wie z.B. CPU-Last, Arbeitsspeicherauslastung, Massenspeicherauslastung, Anzahl der Benutzer, usw.",
    "CPU load" : "CPU-Auslastung",
    "Memory usage" : "Arbeitsspeicher-Auslastung",
    "Active users" : "Aktive Benutzer",
    "Shares" : "Freigaben",
    "Storage" : "Speicher",
    "Users:" : "Benutzer:",
    "Files:" : "Dateien:",
    "Storages:" : "Speicher:",
    "Free Space:" : "Freier Speicherplatz:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Version:",
    "Apps installed:" : "Installierte Apps:",
    "Apps updates available:" : "Apps mit verfügbaren Aktualisierungen:",
    "PHP" : "PHP",
    "Memory Limit:" : "Arbeitspeicher-Grenzwert:",
    "Max Execution Time:" : "Maximale Ausführungszeit:",
    "Upload max size:" : "Maximale Größe zum Hochladen:",
    "Database" : "Datenbank",
    "Type:" : "Art:",
    "Size:" : "Größe:",
    "External monitoring tool" : "Externes Überwachungsprogramm",
    "You can connect an external monitoring tool by using this end point:" : "Durch Verwendung des folgenden Zugangspunktes kann ein externes Überwachungsprogramm verwendet werden: ",
    "Did you know?" : "Wusstest Du schon?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Das Anhängen von \"?format=json\" am Ende der URL gibt Dir das Ergebnis im JSON-Format!",
    "You can connect an external monitoring tool by using this end point: " : "Durch Verwendung des folgenden Zugangspunktes, kann ein externes Überwachungsprogramm verwendet werden:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/de.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informationen zur CPU nicht verfügbar",
    "Load average" : "Durchschnittsauslastung",
    "Last minute" : "Letzte Minute",
    "Memory info not available" : "Informationen zum Arbeitsspeicher nicht verfügbar",
    "Total" : "Gesamt",
    "Current usage" : "Aktuelle Nutzung",
    "Users" : "Benutzer",
    "Groups" : "Gruppen",
    "Links" : "Verknüpfungen",
    "Mails" : "E-Mails",
    "Federated sent" : "Federated gesendet",
    "Federated received" : "Federated empfangen",
    "Talk conversations" : "Talk Unterhaltungen",
    "Last 24 hours" : "Letzte 24 Stunden",
    "Last 1 hour" : "Letzte Stunde",
    "Last 5 mins" : "Letzte 5 Minuten",
    "Copy" : "Kopieren",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Ctrl-C zum Kopieren drücken.",
    "Monitoring" : "Information",
    "Monitoring app with useful server information" : "Monitoring-App mit nützlichen Serverinformationen",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zeigt nützliche Informationen des Servers an wie z.B. CPU-Last, Arbeitsspeicherauslastung, Massenspeicherauslastung, Anzahl der Benutzer, usw.",
    "CPU load" : "CPU-Auslastung",
    "Memory usage" : "Arbeitsspeicher-Auslastung",
    "Active users" : "Aktive Benutzer",
    "Shares" : "Freigaben",
    "Storage" : "Speicher",
    "Users:" : "Benutzer:",
    "Files:" : "Dateien:",
    "Storages:" : "Speicher:",
    "Free Space:" : "Freier Speicherplatz:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Version:",
    "Apps installed:" : "Installierte Apps:",
    "Apps updates available:" : "Apps mit verfügbaren Aktualisierungen:",
    "PHP" : "PHP",
    "Memory Limit:" : "Arbeitspeicher-Grenzwert:",
    "Max Execution Time:" : "Maximale Ausführungszeit:",
    "Upload max size:" : "Maximale Größe zum Hochladen:",
    "Database" : "Datenbank",
    "Type:" : "Art:",
    "Size:" : "Größe:",
    "External monitoring tool" : "Externes Überwachungsprogramm",
    "You can connect an external monitoring tool by using this end point:" : "Durch Verwendung des folgenden Zugangspunktes kann ein externes Überwachungsprogramm verwendet werden: ",
    "Did you know?" : "Wusstest Du schon?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Das Anhängen von \"?format=json\" am Ende der URL gibt Dir das Ergebnis im JSON-Format!"
},
"nplurals=2; plural=(n != 1);");
